@@ -7,5 +7,6 @@ from treetopper.stand import (
     ThinTPA,
     ThinBA,
     ThinRD,
-    FVS
+    FVS,
+    TargetDensityError
 )
\ No newline at end of file
